==> pipewire-docs-1%3A0.3.61-1-armv7h.pkg.tar.xz: usr/share/doc/pipewire/html/group__spa__device.js <==
var group__spa__device =
[
    [ "device.h", "spa_2include_2spa_2monitor_2device_8h.html", null ],
    [ "event.h", "monitor_2event_8h.html", null ],
    [ "type-info.h", "monitor_2type-info_8h.html", null ],
    [ "spa_device", "structspa__device.html", [
      [ "iface", "structspa__device.html#a00d8f19734c35525e99ecaab33113d3f", null ]
    ] ],
    [ "spa_device_info", "structspa__device__info.html", [
      [ "version", "structspa__device__info.html#a394aa2b1d356ce8e510330aedd38ff63", null ],
      [ "change_mask", "structspa__device__info.html#afbe429acf565ab384929f0ccf76fc49c", null ],
      [ "flags", "structspa__device__info.html#a2692374f54a8d9f743474c4a3fcb8ebc", null ],
      [ "params", "structspa__device__info.html#a2ef8690873a8db10e6c29357ea4a216c", null ],
      [ "n_params", "structspa__device__info.html#a5184282839436a8b87d505b4b17cffbd", null ]
    ] ],
    [ "spa_device_object_info", "structspa__device__object__info.html", [
      [ "version", "structspa__device__object__info.html#a0758afd0518197c48d5d76cdc14526e3", null ],
      [ "type", "structspa__device__object__info.html#a4ed767ff310d6f2e1d4cd78f3a7c3f6f", null ],
      [ "factory_name", "structspa__device__object__info.html#a9b6645d2c0b8b3679833ad122cb299a1", null ],
      [ "change_mask", "structspa__device__object__info.html#a702111c5873243c93551073552863666", null ],
      [ "flags", "structspa__device__object__info.html#aec61b33f732c10087d40e9c0d97bdcb0", null ]
    ] ],
    [ "spa_result_device_params", "structspa__result__device__params.html", [
      [ "id", "structspa__result__device__params.html#a19c8bb7f6f09d162006e1a0f0bf98ac9", null ],
      [ "index", "structspa__result__device__params.html#a470559d9b427bffac3b8b13a2e06256a", null ],
      [ "next", "structspa__result__device__params.html#a9076f671dbf2fe3c8e4c39254f9fe058", null ],
      [ "param", "structspa__result__device__params.html#af1baa8eb3700ac09fc9a81a2efd9bebb", null ]
    ] ],
    [ "spa_device_events", "structspa__device__events.html", [
      [ "version", "structspa__device__events.html#ad79a5bdce6b6bd7b299baa38330c96a7", null ],
      [ "info", "structspa__device__events.html#a64cea4459b8c4a483d0a2dd684f3e132", null ],
      [ "result", "structspa__device__events.html#a0b9ba211d7f484c7df9ac269d5b49af3", null ],
      [ "event", "structspa__device__events.html#a5b83e45fd5922657978cc36df24cc1c7", null ],
      [ "object_info", "structspa__device__events.html#a830fadb39e2a8658f9b4cb663619cf4b", null ]
    ] ],
    [ "spa_device_methods", "structspa__device__methods.html", [
      [ "version", "structspa__device__methods.html#a232006e407b2abdb2450a440172186ee", null ],
      [ "add_listener", "structspa__device__methods.html#aac8a0ceced3319473ab3edd4271e1d64", null ],
      [ "sync", "structspa__device__methods.html#a25f49777c2e75988cd5fd7fc490479c8", null ],
      [ "enum_params", "structspa__device__methods.html#a3c9741ff5de62f38f2e3eca50ae24a10", null ],
      [ "set_param", "structspa__device__methods.html#aa5bfc95e88b2f018dddc55fb64899215", null ]
    ] ],
    [ "spa_result_device_params_data", "structspa__result__device__params__data.html", [
      [ "builder", "structspa__result__device__params__data.html#aacff758b17616a531f27a4b8361142ce", null ],
      [ "data", "structspa__result__device__params__data.html#a4b96cf3f827a636bab5ea1ea0a468d38", null ]
    ] ],
    [ "SPA_TYPE_INTERFACE_Device", "group__spa__device.html#ga0ede742404df36a3f585ac584b76c007", null ],
    [ "SPA_VERSION_DEVICE", "group__spa__device.html#ga9041192b59420c24635c77848b5ab7d5", null ],
    [ "SPA_VERSION_DEVICE_INFO", "group__spa__device.html#gaee6259c06260e89b9c7e6186b9975998", null ],
    [ "SPA_DEVICE_CHANGE_MASK_FLAGS", "group__spa__device.html#gaa8e69a2fae59e8d6d1d1da5f0660cbc3", null ],
    [ "SPA_DEVICE_CHANGE_MASK_PROPS", "group__spa__device.html#ga4cde26af07d8cce0804ddb9de69070a5", null ],
    [ "SPA_DEVICE_CHANGE_MASK_PARAMS", "group__spa__device.html#gaf14cd663ab18bce958a27cbfa145a79a", null ],
    [ "SPA_DEVICE_INFO_INIT", "group__spa__device.html#gae60303388ab0418d8f8af5b3e8a80645", null ],
    [ "SPA_VERSION_DEVICE_OBJECT_INFO", "group__spa__device.html#ga0ecfe713ec074a6d73cb8abd986f9ffd", null ],
    [ "SPA_DEVICE_OBJECT_CHANGE_MASK_FLAGS", "group__spa__device.html#gab7ccc98f93f0269396bcbcd3efd1fdb8", null ],
    [ "SPA_DEVICE_OBJECT_CHANGE_MASK_PROPS", "group__spa__device.html#gae5c1deaf4987a5c43c1462e46f18b19b", null ],
    [ "SPA_DEVICE_OBJECT_INFO_INIT", "group__spa__device.html#ga301b070b032f9f696a9bd34e2be08dd1", null ],
    [ "SPA_RESULT_TYPE_DEVICE_PARAMS", "group__spa__device.html#gab347a871f54232e2f8362c60fd893128", null ],
    [ "SPA_DEVICE_EVENT_INFO", "group__spa__device.html#ga9fc516e68fefb9e3c7f08a5fa4ac8242", null ],
    [ "SPA_DEVICE_EVENT_RESULT", "group__spa__device.html#gacbe7c7131058a38cd357c7028387a1ff", null ],
    [ "SPA_DEVICE_EVENT_EVENT", "group__spa__device.html#ga52be50ca0f60cf6fffe0a064be606cf2", null ],
    [ "SPA_DEVICE_EVENT_OBJECT_INFO", "group__spa__device.html#ga4bf09e2b53a707f74b1cf487d1bda6af", null ],
    [ "SPA_DEVICE_EVENT_NUM", "group__spa__device.html#ga1ff1ff0222897525ba3799d0e63ff7c7", null ],
    [ "SPA_VERSION_DEVICE_EVENTS", "group__spa__device.html#gacbbe2dd80be7dac7ffb2e228a244339c", null ],
    [ "SPA_DEVICE_METHOD_ADD_LISTENER", "group__spa__device.html#ga480dd7732417339fcea900102938e822", null ],
    [ "SPA_DEVICE_METHOD_SYNC", "group__spa__device.html#gacbf503314e5bd1a38a9baa23b32dec1c", null ],
    [ "SPA_DEVICE_METHOD_ENUM_PARAMS", "group__spa__device.html#ga956329c75f9076a9de5a2ee8f9cefed3", null ],
    [ "SPA_DEVICE_METHOD_SET_PARAM", "group__spa__device.html#ga64af18e863a2a13cfe4e9ac71adb5b20", null ],
    [ "SPA_DEVICE_METHOD_NUM", "group__spa__device.html#ga7caeded1f3eb1ff8ffce4cedd1b0b7c2", null ],
    [ "SPA_VERSION_DEVICE_METHODS", "group__spa__device.html#gaa6141368f70a58863efc5494673903ba", null ],
    [ "spa_device_method", "group__spa__device.html#ga9bf1b22af1de0ff91ebb45df40d82645", null ],
    [ "spa_device_add_listener", "group__spa__device.html#gae5a43b17b5a707684dfedb342082ef58", null ],
    [ "spa_device_sync", "group__spa__device.html#ga83ed2e7e51ac9f7bc92fa0330b55eb86", null ],
    [ "spa_device_enum_params", "group__spa__device.html#ga79f9c18c7d8738f0cafe71f1ceb66f64", null ],
    [ "spa_device_set_param", "group__spa__device.html#ga3342deed3d0ba9393a405a51af000c74", null ],
    [ "SPA_KEY_DEVICE_ENUM_API", "group__spa__device.html#gae4f6fcd5af1159ca52a6e032174e0555", null ],
    [ "SPA_KEY_DEVICE_API", "group__spa__device.html#gadef390bb7a8fbcfca7bf01639ed6b9e6", null ],
    [ "SPA_KEY_DEVICE_NAME", "group__spa__device.html#ga79781ecdf5018c8f19098debbb40b5d0", null ],
    [ "SPA_KEY_DEVICE_ALIAS", "group__spa__device.html#gad20dd1ca2095057a6af2ad7601947e49", null ],
    [ "SPA_KEY_DEVICE_NICK", "group__spa__device.html#ga951b6e27cbc5b868672a87b8c9b5d818", null ],
    [ "SPA_KEY_DEVICE_DESCRIPTION", "group__spa__device.html#ga0176aee6eac7ee89895ab4f4069afa41", null ],
    [ "SPA_KEY_DEVICE_ICON", "group__spa__device.html#ga85d9cdd3fe854db0c1cda7b46e5a1d34", null ],
    [ "SPA_KEY_DEVICE_ICON_NAME", "group__spa__device.html#ga956f53165732be66eff3cd772e80b7cf", null ],
    [ "SPA_KEY_DEVICE_PLUGGED_USEC", "group__spa__device.html#ga9f19955c5b6a77028eb697a130a5f22e", null ],
    [ "SPA_KEY_DEVICE_BUS_ID", "group__spa__device.html#ga443f624a82ee2787358e46f969904f9d", null ],
    [ "SPA_KEY_DEVICE_BUS_PATH", "group__spa__device.html#gacb844f03c2733e1f62385bf0633aad06", null ],
    [ "SPA_KEY_DEVICE_BUS", "group__spa__device.html#ga10fabcc92b08aee36d96870d881a5fa2", null ],
    [ "SPA_KEY_DEVICE_SUBSYSTEM", "group__spa__device.html#gab68858d85274969e6f2502e95547f429", null ],
    [ "SPA_KEY_DEVICE_SYSFS_PATH", "group__spa__device.html#gae7e76cf0948e77e7ca648babb7f1f210", null ],
    [ "SPA_KEY_DEVICE_VENDOR_ID", "group__spa__device.html#gaf1cc3abc675d1f7369ea994f09fb86b7", null ],
    [ "SPA_KEY_DEVICE_VENDOR_NAME", "group__spa__device.html#ga7ab14f4cccd7c87a8434638429a95c61", null ],
    [ "SPA_KEY_DEVICE_PRODUCT_ID", "group__spa__device.html#ga5fc03e022b6b34a95c40b992b46210b3", null ],
    [ "SPA_KEY_DEVICE_PRODUCT_NAME", "group__spa__device.html#gad97ce15937ee02d483156a0937260f76", null ],
    [ "SPA_KEY_DEVICE_SERIAL", "group__spa__device.html#ga725ef202231224d45f0297aa2c6e84f1", null ],
    [ "SPA_KEY_DEVICE_CLASS", "group__spa__device.html#gae011d2c6dce34040bfe95c9a5b0a8fc4", null ],
    [ "SPA_KEY_DEVICE_CAPABILITIES", "group__spa__device.html#ga31494fdbe7a296b2ab2a12981c88fc4f", null ],
    [ "SPA_KEY_DEVICE_FORM_FACTOR", "group__spa__device.html#ga7a2ffda68c8091296ccbe152e3491a5f", null ],
    [ "SPA_KEY_DEVICE_PROFILE", "group__spa__device.html#ga020999d4feb921cd73b094b826a99d32", null ],
    [ "SPA_KEY_DEVICE_PROFILE_SET", "group__spa__device.html#ga8add515ce73b066a62ccd45232a1b968", null ],
    [ "SPA_KEY_DEVICE_STRING", "group__spa__device.html#ga03e2898800a86dbd2552d293f61c2e23", null ],
    [ "SPA_DEVICE_EVENT_ID", "group__spa__device.html#ga51368ce31a7859fad5132fcc8595d664", null ],
    [ "SPA_DEVICE_EVENT_INIT", "group__spa__device.html#ga976176b17916248c604ae02498d9f648", null ],
    [ "SPA_TYPE_INFO_DeviceEvent", "group__spa__device.html#gac59665317b0bc49197df89771abf6499", null ],
    [ "SPA_TYPE_INFO_DEVICE_EVENT_BASE", "group__spa__device.html#ga8d73dce5d09986b12b102917fb79278b", null ],
    [ "SPA_TYPE_INFO_DeviceEventId", "group__spa__device.html#ga65e21b7134e493124a67e4c582564c29", null ],
    [ "SPA_TYPE_INFO_DEVICE_EVENT_ID_BASE", "group__spa__device.html#ga348873b3533acd66e912773ad9ae740d", null ],
    [ "spa_device_emit", "group__spa__device.html#gabcb2230b6ab2020ceef73fad9e1fd7dc", null ],
    [ "spa_device_emit_info", "group__spa__device.html#ga6573dc405f256f96d9ec6b6518c5c6d8", null ],
    [ "spa_device_emit_result", "group__spa__device.html#ga2bd95e2462bc66fff656e3ce1154a039", null ],
    [ "spa_device_emit_event", "group__spa__device.html#ga1c95c5a55d127c4d928fd30dc0979a7c", null ],
    [ "spa_device_emit_object_info", "group__spa__device.html#ga756d90f78ac51e42bcfd0405b40e2fb9", null ],
    [ "spa_device_event", "group__spa__device.html#ga339438a47cb30c831971c25d7494f2a5", [
      [ "SPA_DEVICE_EVENT_ObjectConfig", "group__spa__device.html#gga339438a47cb30c831971c25d7494f2a5aceb0a1999207e2a7b194acb0bed873d2", null ]
    ] ],
    [ "spa_event_device", "group__spa__device.html#gac7701f46169fcc7a70be0f7167b97cff", [
      [ "SPA_EVENT_DEVICE_START", "group__spa__device.html#ggac7701f46169fcc7a70be0f7167b97cffabdb537e7cf8f7312e5c553dc06428a14", null ],
      [ "SPA_EVENT_DEVICE_Object", "group__spa__device.html#ggac7701f46169fcc7a70be0f7167b97cffa53397e3b7eb932bb53d11a9a56d63ba9", null ],
      [ "SPA_EVENT_DEVICE_Props", "group__spa__device.html#ggac7701f46169fcc7a70be0f7167b97cffaaa0c9d6240dfd91934eaaeea8172f575", null ]
    ] ],
    [ "spa_result_func_device_params", "group__spa__device.html#gafaeb4b272c4322e31836412c4a0c2f74", null ],
    [ "spa_device_enum_params_sync", "group__spa__device.html#gac5d87bd2bc51abe0c370198371428f6f", null ],
    [ "spa_type_device_event_id", "group__spa__device.html#gae3d33bd6e79f4fdb1a19402def48e044", null ],
    [ "spa_type_device_event", "group__spa__device.html#ga6d0493b863780697cf564ff4ae297191", null ]
];

==> pipewire-docs-1%3A0.3.68-2-armv7h.pkg.tar.xz: usr/share/doc/pipewire/html/group__spa__device.js <==
var group__spa__device =
[
    [ "spa/include/spa/monitor/device.h", "spa_2include_2spa_2monitor_2device_8h.html", null ],
    [ "monitor/event.h", "monitor_2event_8h.html", null ],
    [ "monitor/type-info.h", "monitor_2type-info_8h.html", null ],
    [ "spa_device", "structspa__device.html", [
      [ "iface", "structspa__device.html#a00d8f19734c35525e99ecaab33113d3f", null ]
    ] ],
    [ "spa_device_info", "structspa__device__info.html", [
      [ "version", "structspa__device__info.html#a394aa2b1d356ce8e510330aedd38ff63", null ],
      [ "change_mask", "structspa__device__info.html#afbe429acf565ab384929f0ccf76fc49c", null ],
      [ "flags", "structspa__device__info.html#a2692374f54a8d9f743474c4a3fcb8ebc", null ],
      [ "params", "structspa__device__info.html#a2ef8690873a8db10e6c29357ea4a216c", null ],
      [ "n_params", "structspa__device__info.html#a5184282839436a8b87d505b4b17cffbd", null ]
    ] ],
    [ "spa_device_object_info", "structspa__device__object__info.html", [
      [ "version", "structspa__device__object__info.html#a0758afd0518197c48d5d76cdc14526e3", null ],
      [ "type", "structspa__device__object__info.html#a4ed767ff310d6f2e1d4cd78f3a7c3f6f", null ],
      [ "factory_name", "structspa__device__object__info.html#a9b6645d2c0b8b3679833ad122cb299a1", null ],
      [ "change_mask", "structspa__device__object__info.html#a702111c5873243c93551073552863666", null ],
      [ "flags", "structspa__device__object__info.html#aec61b33f732c10087d40e9c0d97bdcb0", null ]
    ] ],
    [ "spa_result_device_params", "structspa__result__device__params.html", [
      [ "id", "structspa__result__device__params.html#a19c8bb7f6f09d162006e1a0f0bf98ac9", null ],
      [ "index", "structspa__result__device__params.html#a470559d9b427bffac3b8b13a2e06256a", null ],
      [ "next", "structspa__result__device__params.html#a9076f671dbf2fe3c8e4c39254f9fe058", null ],
      [ "param", "structspa__result__device__params.html#af1baa8eb3700ac09fc9a81a2efd9bebb", null ]
    ] ],
    [ "spa_device_events", "structspa__device__events.html", [
      [ "version", "structspa__device__events.html#ad79a5bdce6b6bd7b299baa38330c96a7", null ],
      [ "info", "structspa__device__events.html#a64cea4459b8c4a483d0a2dd684f3e132", null ],
      [ "result", "structspa__device__events.html#a0b9ba211d7f484c7df9ac269d5b49af3", null ],
      [ "event", "structspa__device__events.html#a5b83e45fd5922657978cc36df24cc1c7", null ],
      [ "object_info", "structspa__device__events.html#a830fadb39e2a8658f9b4cb663619cf4b", null ]
    ] ],
    [ "spa_device_methods", "structspa__device__methods.html", [
      [ "version", "structspa__device__methods.html#a232006e407b2abdb2450a440172186ee", null ],
      [ "add_listener", "structspa__device__methods.html#aac8a0ceced3319473ab3edd4271e1d64", null ],
      [ "sync", "structspa__device__methods.html#a25f49777c2e75988cd5fd7fc490479c8", null ],
      [ "enum_params", "structspa__device__methods.html#a3c9741ff5de62f38f2e3eca50ae24a10", null ],
      [ "set_param", "structspa__device__methods.html#aa5bfc95e88b2f018dddc55fb64899215", null ]
    ] ],
    [ "spa_result_device_params_data", "structspa__result__device__params__data.html", [
      [ "builder", "structspa__result__device__params__data.html#aacff758b17616a531f27a4b8361142ce", null ],
      [ "data", "structspa__result__device__params__data.html#a4b96cf3f827a636bab5ea1ea0a468d38", null ]
    ] ],
    [ "SPA_TYPE_INTERFACE_Device", "group__spa__device.html#ga0ede742404df36a3f585ac584b76c007", null ],
    [ "SPA_VERSION_DEVICE", "group__spa__device.html#ga9041192b59420c24635c77848b5ab7d5", null ],
    [ "SPA_VERSION_DEVICE_INFO", "group__spa__device.html#gaee6259c06260e89b9c7e6186b9975998", null ],
    [ "SPA_DEVICE_CHANGE_MASK_FLAGS", "group__spa__device.html#gaa8e69a2fae59e8d6d1d1da5f0660cbc3", null ],
    [ "SPA_DEVICE_CHANGE_MASK_PROPS", "group__spa__device.html#ga4cde26af07d8cce0804ddb9de69070a5", null ],
    [ "SPA_DEVICE_CHANGE_MASK_PARAMS", "group__spa__device.html#gaf14cd663ab18bce958a27cbfa145a79a", null ],
    [ "SPA_DEVICE_INFO_INIT", "group__spa__device.html#gae60303388ab0418d8f8af5b3e8a80645", null ],
    [ "SPA_VERSION_DEVICE_OBJECT_INFO", "group__spa__device.html#ga0ecfe713ec074a6d73cb8abd986f9ffd", null ],
    [ "SPA_DEVICE_OBJECT_CHANGE_MASK_FLAGS", "group__spa__device.html#gab7ccc98f93f0269396bcbcd3efd1fdb8", null ],
    [ "SPA_DEVICE_OBJECT_CHANGE_MASK_PROPS", "group__spa__device.html#gae5c1deaf4987a5c43c1462e46f18b19b", null ],
    [ "SPA_DEVICE_OBJECT_INFO_INIT", "group__spa__device.html#ga301b070b032f9f696a9bd34e2be08dd1", null ],
    [ "SPA_RESULT_TYPE_DEVICE_PARAMS", "group__spa__device.html#gab347a871f54232e2f8362c60fd893128", null ],
    [ "SPA_DEVICE_EVENT_INFO", "group__spa__device.html#ga9fc516e68fefb9e3c7f08a5fa4ac8242", null ],
    [ "SPA_DEVICE_EVENT_RESULT", "group__spa__device.html#gacbe7c7131058a38cd357c7028387a1ff", null ],
    [ "SPA_DEVICE_EVENT_EVENT", "group__spa__device.html#ga52be50ca0f60cf6fffe0a064be606cf2", null ],
    [ "SPA_DEVICE_EVENT_OBJECT_INFO", "group__spa__device.html#ga4bf09e2b53a707f74b1cf487d1bda6af", null ],
    [ "SPA_DEVICE_EVENT_NUM", "group__spa__device.html#ga1ff1ff0222897525ba3799d0e63ff7c7", null ],
    [ "SPA_VERSION_DEVICE_EVENTS", "group__spa__device.html#gacbbe2dd80be7dac7ffb2e228a244339c", null ],
    [ "SPA_DEVICE_METHOD_ADD_LISTENER", "group__spa__device.html#ga480dd7732417339fcea900102938e822", null ],
    [ "SPA_DEVICE_METHOD_SYNC", "group__spa__device.html#gacbf503314e5bd1a38a9baa23b32dec1c", null ],
    [ "SPA_DEVICE_METHOD_ENUM_PARAMS", "group__spa__device.html#ga956329c75f9076a9de5a2ee8f9cefed3", null ],
    [ "SPA_DEVICE_METHOD_SET_PARAM", "group__spa__device.html#ga64af18e863a2a13cfe4e9ac71adb5b20", null ],
    [ "SPA_DEVICE_METHOD_NUM", "group__spa__device.html#ga7caeded1f3eb1ff8ffce4cedd1b0b7c2", null ],
    [ "SPA_VERSION_DEVICE_METHODS", "group__spa__device.html#gaa6141368f70a58863efc5494673903ba", null ],
    [ "spa_device_method", "group__spa__device.html#ga9bf1b22af1de0ff91ebb45df40d82645", null ],
    [ "spa_device_add_listener", "group__spa__device.html#gae5a43b17b5a707684dfedb342082ef58", null ],
    [ "spa_device_sync", "group__spa__device.html#ga83ed2e7e51ac9f7bc92fa0330b55eb86", null ],
    [ "spa_device_enum_params", "group__spa__device.html#ga79f9c18c7d8738f0cafe71f1ceb66f64", null ],
    [ "spa_device_set_param", "group__spa__device.html#ga3342deed3d0ba9393a405a51af000c74", null ],
    [ "SPA_KEY_DEVICE_ENUM_API", "group__spa__device.html#gae4f6fcd5af1159ca52a6e032174e0555", null ],
    [ "SPA_KEY_DEVICE_API", "group__spa__device.html#gadef390bb7a8fbcfca7bf01639ed6b9e6", null ],
    [ "SPA_KEY_DEVICE_NAME", "group__spa__device.html#ga79781ecdf5018c8f19098debbb40b5d0", null ],
    [ "SPA_KEY_DEVICE_ALIAS", "group__spa__device.html#gad20dd1ca2095057a6af2ad7601947e49", null ],
    [ "SPA_KEY_DEVICE_NICK", "group__spa__device.html#ga951b6e27cbc5b868672a87b8c9b5d818", null ],
    [ "SPA_KEY_DEVICE_DESCRIPTION", "group__spa__device.html#ga0176aee6eac7ee89895ab4f4069afa41", null ],
    [ "SPA_KEY_DEVICE_ICON", "group__spa__device.html#ga85d9cdd3fe854db0c1cda7b46e5a1d34", null ],
    [ "SPA_KEY_DEVICE_ICON_NAME", "group__spa__device.html#ga956f53165732be66eff3cd772e80b7cf", null ],
    [ "SPA_KEY_DEVICE_PLUGGED_USEC", "group__spa__device.html#ga9f19955c5b6a77028eb697a130a5f22e", null ],
    [ "SPA_KEY_DEVICE_BUS_ID", "group__spa__device.html#ga443f624a82ee2787358e46f969904f9d", null ],
    [ "SPA_KEY_DEVICE_BUS_PATH", "group__spa__device.html#gacb844f03c2733e1f62385bf0633aad06", null ],
    [ "SPA_KEY_DEVICE_BUS", "group__spa__device.html#ga10fabcc92b08aee36d96870d881a5fa2", null ],
    [ "SPA_KEY_DEVICE_SUBSYSTEM", "group__spa__device.html#gab68858d85274969e6f2502e95547f429", null ],
    [ "SPA_KEY_DEVICE_SYSFS_PATH", "group__spa__device.html#gae7e76cf0948e77e7ca648babb7f1f210", null ],
    [ "SPA_KEY_DEVICE_VENDOR_ID", "group__spa__device.html#gaf1cc3abc675d1f7369ea994f09fb86b7", null ],
    [ "SPA_KEY_DEVICE_VENDOR_NAME", "group__spa__device.html#ga7ab14f4cccd7c87a8434638429a95c61", null ],
    [ "SPA_KEY_DEVICE_PRODUCT_ID", "group__spa__device.html#ga5fc03e022b6b34a95c40b992b46210b3", null ],
    [ "SPA_KEY_DEVICE_PRODUCT_NAME", "group__spa__device.html#gad97ce15937ee02d483156a0937260f76", null ],
    [ "SPA_KEY_DEVICE_SERIAL", "group__spa__device.html#ga725ef202231224d45f0297aa2c6e84f1", null ],
    [ "SPA_KEY_DEVICE_CLASS", "group__spa__device.html#gae011d2c6dce34040bfe95c9a5b0a8fc4", null ],
    [ "SPA_KEY_DEVICE_CAPABILITIES", "group__spa__device.html#ga31494fdbe7a296b2ab2a12981c88fc4f", null ],
    [ "SPA_KEY_DEVICE_FORM_FACTOR", "group__spa__device.html#ga7a2ffda68c8091296ccbe152e3491a5f", null ],
    [ "SPA_KEY_DEVICE_PROFILE", "group__spa__device.html#ga020999d4feb921cd73b094b826a99d32", null ],
    [ "SPA_KEY_DEVICE_PROFILE_SET", "group__spa__device.html#ga8add515ce73b066a62ccd45232a1b968", null ],
    [ "SPA_KEY_DEVICE_STRING", "group__spa__device.html#ga03e2898800a86dbd2552d293f61c2e23", null ],
    [ "SPA_DEVICE_EVENT_ID", "group__spa__device.html#ga51368ce31a7859fad5132fcc8595d664", null ],
    [ "SPA_DEVICE_EVENT_INIT", "group__spa__device.html#ga976176b17916248c604ae02498d9f648", null ],
    [ "SPA_TYPE_INFO_DeviceEvent", "group__spa__device.html#gac59665317b0bc49197df89771abf6499", null ],
    [ "SPA_TYPE_INFO_DEVICE_EVENT_BASE", "group__spa__device.html#ga8d73dce5d09986b12b102917fb79278b", null ],
    [ "SPA_TYPE_INFO_DeviceEventId", "group__spa__device.html#ga65e21b7134e493124a67e4c582564c29", null ],
    [ "SPA_TYPE_INFO_DEVICE_EVENT_ID_BASE", "group__spa__device.html#ga348873b3533acd66e912773ad9ae740d", null ],
    [ "spa_device_emit", "group__spa__device.html#gabcb2230b6ab2020ceef73fad9e1fd7dc", null ],
    [ "spa_device_emit_info", "group__spa__device.html#ga6573dc405f256f96d9ec6b6518c5c6d8", null ],
    [ "spa_device_emit_result", "group__spa__device.html#ga2bd95e2462bc66fff656e3ce1154a039", null ],
    [ "spa_device_emit_event", "group__spa__device.html#ga1c95c5a55d127c4d928fd30dc0979a7c", null ],
    [ "spa_device_emit_object_info", "group__spa__device.html#ga756d90f78ac51e42bcfd0405b40e2fb9", null ],
    [ "spa_device_event", "group__spa__device.html#ga339438a47cb30c831971c25d7494f2a5", [
      [ "SPA_DEVICE_EVENT_ObjectConfig", "group__spa__device.html#gga339438a47cb30c831971c25d7494f2a5aceb0a1999207e2a7b194acb0bed873d2", null ]
    ] ],
    [ "spa_event_device", "group__spa__device.html#gac7701f46169fcc7a70be0f7167b97cff", [
      [ "SPA_EVENT_DEVICE_START", "group__spa__device.html#ggac7701f46169fcc7a70be0f7167b97cffabdb537e7cf8f7312e5c553dc06428a14", null ],
      [ "SPA_EVENT_DEVICE_Object", "group__spa__device.html#ggac7701f46169fcc7a70be0f7167b97cffa53397e3b7eb932bb53d11a9a56d63ba9", null ],
      [ "SPA_EVENT_DEVICE_Props", "group__spa__device.html#ggac7701f46169fcc7a70be0f7167b97cffaaa0c9d6240dfd91934eaaeea8172f575", null ]
    ] ],
    [ "spa_result_func_device_params", "group__spa__device.html#gafaeb4b272c4322e31836412c4a0c2f74", null ],
    [ "spa_device_enum_params_sync", "group__spa__device.html#gac5d87bd2bc51abe0c370198371428f6f", null ],
    [ "spa_type_device_event_id", "group__spa__device.html#gae3d33bd6e79f4fdb1a19402def48e044", null ],
    [ "spa_type_device_event", "group__spa__device.html#ga6d0493b863780697cf564ff4ae297191", null ]
];
